Crate hexga_io

Crate hexga_io 

Modules

fs
Filesystem manipulation operations.
io
Traits, helpers, and type definitions for core I/O functionality.
prelude
traits

Structs

IoData
Access the data folder where the exe is stored.
IoExe
Access to the path where the exe is stored.
IoGlobal
The Global I/O operations for the filesystem. It have access to the whole file system. Use other Io struct to sandbox it.
Path
A slice of a path (akin to str).
PathBuf
An owned, mutable path (akin to String).

Enums

FileKind

Traits

FileSystem
FileSystemIsolated
FileSystemProvider
FileSystemRead
FileSystemWrite
FileTypeExtension
GetPath
IoErrorExt
SetPath

Type Aliases

FileType
IoError
IoErrorKind
IoResult